#' @title Running Mplus for testing empirical RIASEC angular locations
#' @export Circ_test
#' @description This function generates and runs Mplus syntax which is discussed in Nagy et. al. (2009) and extracts the estimated model fit - tested against given (perfect - as default) angular locations of the six RIASEC dimensions, based on their correlations, in the asumed circumplex array within the theory of vocational choice by John Holland (1997).
#' @details more to come ...
#' 
#' @param N number of observations for correlations as numeric
#' @param Kor either an R matrix object with RIASEC correlations or the name of a correlation matrix, stored as a .dat text file, as character (see details).  
#' @param test either character (default test="perfect"), whicht tests against a perfect circumplex array, or a numeric vector with length = 6 giving the six angular locations (in radians) to test against.
#' @param w logical - write fit coefficiants as csv table? - default: \code{w = FALSE}.
#' @param showOutput default set to \code{TRUE} - see description of the function \code{runModels()} in package \code{\link[MplusAutomation]{MplusAutomation}}.
#' @param Mplus_command default set to \code{"/Applications/Mplus\ 7/mplus"} for MAC OS X systems having Mplus version 7 installed in an sub directory namend "Mplus 7" in Applications folder. Windows users having Mplus installed with the standard settings should change the argument to \code{Mplus_command="mplus"} - see examples and see description of the function \code{runModels()} in package \code{\link[MplusAutomation]{MplusAutomation}}.
#' @param replaceOutfile default set to "always" - see description of the function \code{runModels()} in package \code{\link[MplusAutomation]{MplusAutomation}}.
#' @param name optional a name (as character) for the Mplus syntax to be saved - default is the object name or the name given in paramter \code{Kor} as character (with ending changed to '.inp').
#' @param ... additional parameters passed through
#' @return a list fith fit indices. And resulting Mplus syntax wil be saved in the current working directory
#' @references Holland, J.L. (1997). \emph{Making vocational choices. A theory of vocational personalities and work environments}. Lutz, FL: Psychological Assessment Resources.
#' @references Nagy, G., Marsh, H. W., Luedtke, O., & Trautwein, U. (2009). Representing circles in our minds: Confirmatory factor analysis of circumplex structures and profiles. In T. Teo & M. S. Khine (Hrsg.), \emph{Structural Equation Modeling in Educational Research: Concepts and applications} (S. 287 - 315). Rotterdam Boston Taipei: Sense Publishers.
#' 
#' @examples ## generating runing and ectractin Mplus files refering to a correlation data stored in the already existing text file example1.dat
#' data(example2) # loading fictional example correlation matrix
#' # not Run until Mplus is installed on your Sytem #####
#' #----------choose your system !---------------------------------------
#' # MAC user:     test <- Circ_test(N = 300, Kor = example2, test="perfect") 
#' # Windows user: test <- CCirc_test(N = 300, Kor = example2, test="perfect",Mplus_command="mplus")
#' #---------------------------------------------------------------------
#' # test 

############## funktions beginn ####
# erzeugen eines Mplus Syntaxes nach Nagy(2009) - test against a perfect circumplex 
Circ_test <-function(N,Kor, test = "perfect",w=FALSE ,showOutput=TRUE,Mplus_command="/Applications/Mplus\ 7/mplus", replaceOutfile= "always",name="", ...) 
{
  if(class(Kor)=="character"){
    if(unlist(strsplit(Kor,".",fixed=T))[2]!="dat") { 
      cat("name for correlation matrix should end with '.dat'","\n")
      stopifnot(unlist(strsplit(Kor,".",fixed=T))[2]!="dat")
    }
    if(unlist(strsplit(Kor,".",fixed=T))[2]=="dat" & name=="") { 
      name<-paste(unlist(strsplit(Kor,".",fixed=T))[1],".inp",sep="")
    }
    if(unlist(strsplit(name,".",fixed=T))[2]!="inp"){
      cat("name for Mplus syntax should end with '.inp'","\n")
      stopifnot(unlist(strsplit(name,".",fixed=T))[2]=="inp")                                                  
    }
  }
  
  if(class(Kor)=="matrix" & name==""){
    name = paste(deparse(substitute(Kor)),".inp",sep="")
    if(dim(Kor)[1]!=dim(Kor)[2]){cat("correlation matrix '",deparse(substitute(Kor)), "' is not symetric!","\n",sep="")}
    stopifnot(dim(Kor)[1]==dim(Kor)[2])
    writedat(ob=Kor,file = paste(deparse(substitute(Kor)),".dat",sep="") )
    Kor<-paste(deparse(substitute(Kor)),".dat",sep="")
  }
 ######################################
 Mplus_tsyn(N, Kor,test = test ,name = name)
  
 runModels(showOutput=showOutput,replaceOutfile=replaceOutfile, Mplus_command=Mplus_command,...)
  
 return( Mplus_fit(target=paste(unlist(strsplit(name,".",fixed=T))[1],".out",sep=""), w=w))  
}